==> moodle_1.3.1.orig.tar.gz: moodle/lang/pt/forum.php <==
<?PHP // $Id: forum.php,v 1.9 2004/04/27 11:59:54 villate Exp $ 
      // forum.php - created with Moodle 1.2.1 (2004032500)


$string['addanewdiscussion'] = 'Adicione um novo tpico de discusso';
$string['addanewtopic'] = 'Adicionar um novo tpico';
$string['allowchoice'] = 'Permitir a todos escolher';
$string['allowdiscussions'] = 'Permitir um $a comear novas discusses?';
$string['allowratings'] = 'Permitir classificar respostas?';
$string['allowsdiscussions'] = 'Este forum permite cada pessoa comear um tpico de discusso.';
$string['anyfile'] = 'Qualquer ficheiro';
$string['attachment'] = 'Anexo';
$string['bynameondate'] = 'por $a->name - $a->date';
$string['configdisplaymode'] = 'Modo de visualizao prdefinido para as discusses se nenhum for definido.';
$string['configlongpost'] = 'Qualquer mensagem acima deste tamanho (sem incluir HTML) ser considerada longa.';
$string['configmanydiscussions'] = 'Nmero mximo de discusses visualizadas num forum por pgina';
$string['configmaxbytes'] = 'Tamanho mximo, por omisso, para os anexos enviados em mensagens para os foruns (sujeito a outros limites impostos pela disciplina e pelo servidor)';
$string['configshortpost'] = 'Qualquer mensagem abaixo deste tamanho (sem incluir HTML) ser considerada curta.';
$string['couldnotadd'] = 'No  possvel adicionar o seu tpico devido a um erro desconhecido';
$string['couldnotdeleteratings'] = 'Desculpe, isso no pode ser apagado pois j algum deu-lhe uma classificao';
$string['couldnotdeletereplies'] = 'Desculpe, isso no pode ser apagado pois j algum envio uma resposta.';
$string['couldnotupdate'] = 'No  possvel actualizar o seu tpico devido a um erro desconhecido';
$string['delete'] = 'Apagar';
$string['deleteddiscussion'] = 'O tpico de discusso foi apagado';
$string['deletedpost'] = 'A mensagem foi apagada';
$string['deletesure'] = 'Tem certeza que quer apagar esta mensagem?';
$string['discussion'] = 'Discusso';
$string['discussionmoved'] = 'Esta discusso foi movida para \'$a\'.';
$string['discussions'] = 'Discusses';
$string['discussionsstartedby'] = 'Discusses iniciadas por $a';
$string['discussionsstartedbyrecent'] = 'Discusses iniciadas recentemente por $a';
$string['discussthistopic'] = 'Discuta este tpico';
$string['eachuserforum'] = 'Cada pessoa envia uma discusso';
$string['edit'] = 'Editar';
$string['editing'] = 'Editando';
$string['emptymessage'] = 'Algo estava errado na sua contribuio. Talvez estava em branco ou um anexo era muito grande. As suas alteraes no foram gravadas.';
$string['everyonecanchoose'] = 'Todos podem decidir a sua inscrio';
$string['everyoneissubscribed'] = 'Todos sero inscritos neste forum';
$string['forcesubscribe'] = 'Obriga a todos a estarem inscritos';
$string['forcesubscribeq'] = 'Obrigar a todos a estar inscritos?';
$string['forum'] = 'Forum';
$string['forumintro'] = 'Introduo ao Forum';
$string['forumname'] = 'Nome do Forum';
$string['forums'] = 'Foruns';
$string['forumtype'] = 'Tipo de Forum';
$string['generalforum'] = 'Forum genrico para uso geral';
$string['generalforums'] = 'Foruns gerais';
$string['inforum'] = 'em $a';
$string['intronews'] = 'Notcias gerais e anncios';
$string['introsocial'] = 'Um forum aberto para conversar sobre qualquer coisa que quiser';
$string['introteacher'] = 'Um forum para professores - s notas e discusso';
$string['lastpost'] = 'ltima mensagem';
$string['learningforums'] = 'Foruns de aprendizagem';
$string['maxattachmentsize'] = 'Tamanho mximo do anexo';
$string['maxtimehaspassed'] = 'Desculpe, mas ultrapassou o tempo mximo para editar este tpico ($a)!';
$string['message'] = 'Mensagem';
$string['modeflatnewestfirst'] = 'Listagem de respostas, com a mais nova primeiro';
$string['modeflatoldestfirst'] = 'Listagem de respostas, com a mais velha primeiro';
$string['modenested'] = 'Mostrar respostas em forma hierrquica';
$string['modethreaded'] = 'Mostrar respostas por fios de discusso';
$string['modulename'] = 'Forum';
$string['modulenameplural'] = 'Foruns';
$string['more'] = 'mais';
$string['movethisdiscussionto'] = 'Mover esta discusso para ...';
$string['namenews'] = 'Notcias';
$string['namesocial'] = 'Forum social';
$string['nameteacher'] = 'Forum de professores';
$string['newforumposts'] = 'Novas mensagens no forum';
$string['nodiscussions'] = 'No h nenhum tpico de discusso presente neste forum';
$string['noguestpost'] = 'Lamentamos informar que como visitante no pode enviar mensagens neste forum';
$string['nomorepostscontaining'] = 'No foram encontradas mais mensagens contendo \'$a\'';
$string['nonews'] = 'Ainda no foram publicadas notcias';
$string['noposts'] = 'Nenhuma mensagem';
$string['nopostscontaining'] = 'Nenhuma mensagem \'$a\' encontrada';
$string['nosubscribers'] = 'No h nenhum subscritor ainda neste forum';
$string['notingroup'] = 'Lamentamos, mas tem que pertencer a algum grupo para poder aceder a este forum.';
$string['nownotsubscribed'] = '$a->name no receber cpias de \'$a->forum\' atravs do correio.';
$string['nowsubscribed'] = '$a->name receber cpias de \'$a->forum\' atravs do correio.';
$string['numposts'] = '$a mensagens';
$string['olderdiscussions'] = 'Discusses mais antigas';
$string['openmode0'] = 'Nenhuma discusso nem respostas';
$string['openmode1'] = 'Nenhuma discusso, mas so permitidas respostas';
$string['openmode2'] = 'So permitidas discusses e respostas';
$string['parent'] = 'Mostre o pai';
$string['parentofthispost'] = 'Padre desta mensagem';
$string['postadded'] = '<p>A sua mensagem foi inserida com sucesso.</p><p>Tem $a para a editar se quiser fazer alteraes.</p>';
$string['postincontext'] = 'Veja esta mensagem no contexto';
$string['postmailinfo'] = 'Esta  uma cpia de uma mensagem enviada para o stio web de $a.
Para enviar uma resposta para o forum, use o apontador que se segue:';
$string['postrating1'] = 'Contribui principalmente para a aprendizagem INDIVIDUAL';
$string['postrating2'] = 'Aprendizagem Individual e Colectiva por igual';
$string['postrating3'] = 'Contribui principalmente para a aprendizagem COLECTIVA';
$string['posts'] = 'Mensagens';
$string['postupdated'] = 'A sua mensagem foi actualizada';
$string['processingpost'] = 'A processar a mensagem $a';
$string['rate'] = 'Taxa';
$string['rating'] = 'Classificao';
$string['ratingeveryone'] = 'Toda a gente pode classificar mensagens';
$string['ratingno'] = 'No h classificaes';
$string['ratingonlyteachers'] = 'Apenas $a pode classificar mensagens';
$string['ratingpublic'] = '$a pode ver as classificaes de todos';
$string['ratingpublicnot'] = '$a pode ver unicamente as suas prprias classificaes';
$string['ratings'] = 'Classificaes';
$string['ratingssaved'] = 'As classificaes foram gravadas';
$string['ratingsuse'] = 'Utilizar classificaes';
$string['ratingtime'] = 'Restringir classificaes a mensagens enviadas dentro deste intervalo de datas:';
$string['re'] = 'Re:';
$string['readtherest'] = 'Leia o resto deste tpico';
$string['replies'] = 'Respostas';
$string['repliesmany'] = '$a respostas, por enquanto';
$string['repliesone'] = '$a resposta, por enquanto';
$string['reply'] = 'Responder';
$string['replyforum'] = 'Responder para o forum';
$string['search'] = 'Procurar';
$string['searchforums'] = 'Procurar nos foruns';
$string['searcholderposts'] = 'Porcurar mensagens antigas...';
$string['searchresults'] = 'Procurar resultados';
$string['sendinratings'] = 'Enviar as minhas ltimas classificaes';
$string['showsubscribers'] = 'Mostrar/editar subscritores actuais';
$string['singleforum'] = 'Uma nica discusso simples';
$string['startedby'] = 'Iniciado por';
$string['subject'] = 'Assunto';
$string['subscribe'] = 'Subscrever a este forum';
$string['subscribeall'] = 'Subscrever todos neste forum';
$string['subscribed'] = 'Subscrito';
$string['subscribenone'] = 'Desubscrever todos deste forum';
$string['subscribers'] = 'Subscritores';
$string['subscribersto'] = 'Subscritores para \'$a\'';
$string['subscribestart'] = 'Envie-me cpias de mensagens deste forum por email';
$string['subscribestop'] = 'No me envie cpias de mensagens deste forum por email';
$string['subscription'] = 'Subscrio';
$string['subscriptions'] = 'Subscries';
$string['unsubscribe'] = 'Cancelar a subscrio a este forum';
$string['unsubscribed'] = 'Subscrio cancelada';
$string['unsubscribeshort'] = 'Desubscrever';
$string['youratedthis'] = 'Voc avaliou este';
$string['yournewtopic'] = 'Seu novo tpico de discusso';
$string['yourreply'] = 'A sua resposta';

?>

==> moodle_1.4.4.dfsg.1.orig.tar.gz: moodle/lang/pt/forum.php <==
<?PHP // $Id$ 
      // forum.php - created with Moodle 1.4 development (2004062600)


$string['addanewdiscussion'] = 'Adicione um novo tpico de discusso';
$string['addanewtopic'] = 'Adicionar um novo tpico';
$string['allowchoice'] = 'Permitir a todos escolher';
$string['allowdiscussions'] = 'Permitir um $a comear novas discusses?';
$string['allowratings'] = 'Permitir classificar respostas?';
$string['allowsdiscussions'] = 'Este forum permite cada pessoa comear um tpico de discusso.';
$string['anyfile'] = 'Qualquer ficheiro';
$string['attachment'] = 'Anexo';
$string['bynameondate'] = 'por $a->name - $a->date';
$string['configdisplaymode'] = 'Modo de visualizao prdefinido para as discusses se nenhum for definido.';
$string['configenablerssfeeds'] = 'Esta opo activar a posibilidade de usar listagens  RSS para todos os foruns. Ser ainda preciso activar a opo manualmente em cada forum.';
$string['configlongpost'] = 'Qualquer mensagem acima deste tamanho (sem incluir HTML) ser considerada longa.';
$string['configmanydiscussions'] = 'Nmero mximo de discusses visualizadas num forum por pgina';
$string['configmaxbytes'] = 'Tamanho mximo, por omisso, para os anexos enviados em mensagens para os foruns (sujeito a outros limites impostos pela disciplina e pelo servidor)';
$string['configreplytouser'] = 'Quando uma mensagem de um forum for distribuida pelo correio electrnico, dever conter o endereo do autor para que os destinatrios possam responder directamente em vez de usarem o forum? Embora responda aqui que sim, os utilizadores podem ainda decidir no seu perfil se no quiserem que o seu endereo seja divulgado.';
$string['configshortpost'] = 'Qualquer mensagem abaixo deste tamanho (sem incluir HTML) ser considerada curta.';
$string['couldnotadd'] = 'No  possvel adicionar o seu tpico devido a um erro desconhecido';
$string['couldnotdeleteratings'] = 'Desculpe, isso no pode ser apagado pois j algum deu-lhe uma classificao';
$string['couldnotdeletereplies'] = 'Desculpe, isso no pode ser apagado pois j algum envio uma resposta.';
$string['couldnotupdate'] = 'No  possvel actualizar o seu tpico devido a um erro desconhecido';
$string['delete'] = 'Apagar';
$string['deleteddiscussion'] = 'O tpico de discusso foi apagado';
$string['deletedpost'] = 'A mensagem foi apagada';
$string['deletesure'] = 'Tem certeza que quer apagar esta mensagem?';
$string['digestmailheader'] = 'Este  o seu sumrio dirio de novas mensagens nos foruns de $a->sitename. Para alterar as suas preferncias no forum, visite $a->userprefs. ';
$string['digestmailprefs'] = 'o seu perfil de utilizador';
$string['digestmailsubject'] = '$a: sumrio do forum';
$string['digestsentusers'] = 'Sumrios de foruns enviados com sucesso para $a utilizadores. ';
$string['discussion'] = 'Discusso';
$string['discussionmoved'] = 'Esta discusso foi movida para \'$a\'.';
$string['discussionname'] = 'Ttulo da discusso';
$string['discussions'] = 'Discusses';
$string['discussionsstartedby'] = 'Discusses iniciadas por $a';
$string['discussionsstartedbyrecent'] = 'Discusses iniciadas recentemente por $a';
$string['discussthistopic'] = 'Discuta este tpico';
$string['eachuserforum'] = 'Cada pessoa envia uma discusso';
$string['edit'] = 'Editar';
$string['editing'] = 'Editando';
$string['emptymessage'] = 'Algo estava errado na sua contribuio. Talvez estava em branco ou um anexo era muito grande. As suas alteraes no foram gravadas.';
$string['everyonecanchoose'] = 'Todos podem decidir a sua inscrio';
$string['everyoneissubscribed'] = 'Todos sero inscritos neste forum';
$string['forcesubscribe'] = 'Obriga a todos a estarem inscritos';
$string['forcesubscribeq'] = 'Obrigar a todos a estar inscritos?';
$string['forum'] = 'Forum';
$string['forumintro'] = 'Introduo ao Forum';
$string['forumname'] = 'Nome do Forum';
$string['forums'] = 'Foruns';
$string['forumtype'] = 'Tipo de Forum';
$string['generalforum'] = 'Forum genrico para uso geral';
$string['generalforums'] = 'Foruns gerais';
$string['inforum'] = 'em $a';
$string['intronews'] = 'Notcias gerais e anncios';
$string['introsocial'] = 'Um forum aberto para conversar sobre qualquer coisa que quiser';
$string['introteacher'] = 'Um forum para professores - s notas e discusso';
$string['lastpost'] = 'ltima mensagem';
$string['learningforums'] = 'Foruns de aprendizagem';
$string['maxattachmentsize'] = 'Tamanho mximo do anexo';
$string['maxtimehaspassed'] = 'Desculpe, mas ultrapassou o tempo mximo para editar este tpico ($a)!';
$string['message'] = 'Mensagem';
$string['modeflatnewestfirst'] = 'Listagem de respostas, com a mais nova primeiro';
$string['modeflatoldestfirst'] = 'Listagem de respostas, com a mais velha primeiro';
$string['modenested'] = 'Mostrar respostas em forma hierrquica';
$string['modethreaded'] = 'Mostrar respostas por fios de discusso';
$string['modulename'] = 'Forum';
$string['modulenameplural'] = 'Foruns';
$string['more'] = 'mais';
$string['movethisdiscussionto'] = 'Mover esta discusso para ...';
$string['namenews'] = 'Notcias';
$string['namesocial'] = 'Forum social';
$string['nameteacher'] = 'Forum de professores';
$string['newforumposts'] = 'Novas mensagens no forum';
$string['nodiscussions'] = 'No h nenhum tpico de discusso presente neste forum';
$string['noguestpost'] = 'Lamentamos informar que como visitante no pode enviar mensagens neste forum';
$string['nomorepostscontaining'] = 'No foram encontradas mais mensagens contendo \'$a\'';
$string['nonews'] = 'Ainda no foram publicadas notcias';
$string['noposts'] = 'Nenhuma mensagem';
$string['nopostscontaining'] = 'Nenhuma mensagem \'$a\' encontrada';
$string['nosubscribers'] = 'No h nenhum subscritor ainda neste forum';
$string['notingroup'] = 'Lamentamos, mas tem que pertencer a algum grupo para poder aceder a este forum.';
$string['nownotsubscribed'] = '$a->name no receber cpias de \'$a->forum\' atravs do correio.';
$string['nowsubscribed'] = '$a->name receber cpias de \'$a->forum\' atravs do correio.';
$string['numposts'] = '$a mensagens';
$string['olderdiscussions'] = 'Discusses mais antigas';
$string['openmode0'] = 'Nenhuma discusso nem respostas';
$string['openmode1'] = 'Nenhuma discusso, mas so permitidas respostas';
$string['openmode2'] = 'So permitidas discusses e respostas';
$string['parent'] = 'Mostre o pai';
$string['parentofthispost'] = 'Padre desta mensagem';
$string['postadded'] = '<p>A sua mensagem foi inserida com sucesso.</p><p>Tem $a para a editar se quiser fazer alteraes.</p>';
$string['postincontext'] = 'Veja esta mensagem no contexto';
$string['postmailinfo'] = 'Esta  uma cpia de uma mensagem enviada para o stio web de $a.
Para enviar uma resposta para o forum, use o apontador que se segue:';
$string['postrating1'] = 'Contribui principalmente para a aprendizagem INDIVIDUAL';
$string['postrating2'] = 'Aprendizagem Individual e Colectiva por igual';
$string['postrating3'] = 'Contribui principalmente para a aprendizagem COLECTIVA';
$string['posts'] = 'Mensagens';
$string['posttoforum'] = 'Enviar para o forum';
$string['postupdated'] = 'A sua mensagem foi actualizada';
$string['processingdigest'] = 'A processar mensagem de sumrio para o utilizador $a';
$string['processingpost'] = 'A processar a mensagem $a';
$string['prune'] = 'Dividir';
$string['prunedpost'] = 'Uma nova discusso foi criada a raiz dessa mensagem';
$string['pruneheading'] = 'Divida a discusso passando esta mensagem para uma nova discusso';
$string['rate'] = 'Taxa';
$string['rating'] = 'Classificao';
$string['ratingeveryone'] = 'Toda a gente pode classificar mensagens';
$string['ratingno'] = 'No h classificaes';
$string['ratingonlyteachers'] = 'Apenas $a pode classificar mensagens';
$string['ratingpublic'] = '$a pode ver as classificaes de todos';
$string['ratingpublicnot'] = '$a pode ver unicamente as suas prprias classificaes';
$string['ratings'] = 'Classificaes';
$string['ratingssaved'] = 'As classificaes foram gravadas';
$string['ratingsuse'] = 'Utilizar classificaes';
$string['ratingtime'] = 'Restringir classificaes a mensagens enviadas dentro deste intervalo de datas:';
$string['re'] = 'Re:';
$string['readtherest'] = 'Leia o resto deste tpico';
$string['replies'] = 'Respostas';
$string['repliesmany'] = '$a respostas, por enquanto';
$string['repliesone'] = '$a resposta, por enquanto';
$string['reply'] = 'Responder';
$string['replyforum'] = 'Responder para o forum';
$string['rsssubscriberssdiscussions'] = 'Mostrar a listagem RSS para \'$a\' discusses';
$string['rsssubscriberssposts'] = 'Mostrar a listagem RSS para \'$a\' mensagens';
$string['search'] = 'Procurar';
$string['searchforums'] = 'Procurar nos foruns';
$string['searcholderposts'] = 'Porcurar mensagens antigas...';
$string['searchresults'] = 'Procurar resultados';
$string['sendinratings'] = 'Enviar as minhas ltimas classificaes';
$string['showsubscribers'] = 'Mostrar/editar subscritores actuais';
$string['singleforum'] = 'Uma nica discusso simples';
$string['startedby'] = 'Iniciado por';
$string['subject'] = 'Assunto';
$string['subscribe'] = 'Subscrever a este forum';
$string['subscribeall'] = 'Subscrever todos neste forum';
$string['subscribed'] = 'Subscrito';
$string['subscribenone'] = 'Desubscrever todos deste forum';
$string['subscribers'] = 'Subscritores';
$string['subscribersto'] = 'Subscritores para \'$a\'';
$string['subscribestart'] = 'Envie-me cpias de mensagens deste forum por email';
$string['subscribestop'] = 'No me envie cpias de mensagens deste forum por email';
$string['subscription'] = 'Subscrio';
$string['subscriptions'] = 'Subscries';
$string['unsubscribe'] = 'Cancelar a subscrio a este forum';
$string['unsubscribed'] = 'Subscrio cancelada';
$string['unsubscribeshort'] = 'Desubscrever';
$string['youratedthis'] = 'Voc avaliou este';
$string['yournewtopic'] = 'Seu novo tpico de discusso';
$string['yourreply'] = 'A sua resposta';

?>
